@@ -121,6 +121,8 @@ class ZbxCommon(object):
         self.obj_token=''
         self.auth_uuid=''
         self.token=''
+        if len(sys.argv)==2 and len(sys.argv[1])==36:
+            self.get_param('')
 
     def init_log(self):
         global logger,IS_INIT_GLOBAL_LOG
